@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: afunix.c,v 1.22 2002/07/18 13:18:01 bazsi Exp $
+ * $Id: afunix.c,v 1.23 2002/08/21 14:03:50 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -51,7 +51,7 @@ do_init_afunix_connection(struct log_handler *c,
 	CAST(afsocket_source_connection, self, c);
 
 	io_read(self->client, 
-		make_log_reader(0, NULL, cfg->log_msg_size, 0, c), 
+		make_log_reader(0, NULL, cfg->log_msg_size, 0, cfg->check_hostname ? LF_CHECK_HOSTNAME : 0, c), 
 		make_afsocket_source_close_callback(self));
 	
 	return ST_OK | ST_GOON;
