@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: main.c,v 1.42 2002/06/17 09:23:13 bazsi Exp $
+ * $Id: main.c,v 1.43 2002/08/21 14:03:50 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -185,7 +185,7 @@ int main_loop(struct syslog_backend *backend)
 	s.timeout = backend->configuration->stats_freq;
 	s.backend = backend;
 	r.backend = backend;
-	if (s.timeout <= 0)
+	if (s.timeout > 0)
 		io_callout(&backend->super, s.timeout, &s.super);
 
 	while (io_iter(&backend->super)) {
@@ -201,7 +201,7 @@ int main_loop(struct syslog_backend *backend)
 				io_callout_flush(&backend->super);
 
 				s.timeout = backend->configuration->stats_freq;
-				if (s.timeout <= 0)
+				if (s.timeout > 0)
 					io_callout(&backend->super, s.timeout, &s.super);
 				
 				r.state = 0;
