@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: sources.c,v 1.34 2002/07/18 13:18:02 bazsi Exp $
+ * $Id: sources.c,v 1.35 2002/08/21 14:03:50 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -53,6 +53,7 @@
 	 (buffer space UINT8)
 	 (max_log_line simple UINT32)
 	 (pad_size simple UINT32)
+	 (msg_flags simple UINT32)
          (next object log_handler)))
 */
 
@@ -64,7 +65,7 @@ do_handle_line(struct log_reader *self,
 {
 	struct log_info *logmsg;
 
-	logmsg = make_log_info(length, data, self->prefix);
+	logmsg = make_log_info(length, data, self->prefix, self->msg_flags);
 	if (addrlen) {
 		logmsg->saddr = sockaddr2address_info(addrlen, addr);
 	}
@@ -112,8 +113,11 @@ do_read_line(struct read_handler **h,
 		closure->pos = 0;
 		return ST_OK | ST_GOON;
 	}
-	if (!eol && closure->pos) {
-		/* we don't have a terminating nl nor \0 */
+	if (!eol && (closure->dgram || closure->pos == closure->max_log_line)) {
+		/* we don't have a terminating nl nor \0, and our buffer is
+		   full or we are a datagram receiver, when the message is in
+		   its own packet.
+		 */
 		do_handle_line(closure, closure->pos, closure->buffer, salen ? (abstract_addr *) &sabuf : NULL, salen);
 		closure->pos = 0;
 		return ST_OK | ST_GOON;
@@ -150,6 +154,7 @@ make_log_reader(UINT32 dgram,
 		UINT8 *prefix,
 		UINT32 max_log_line,
 		UINT32 pad_size,
+		UINT32 msg_flags,
 		struct log_handler *next)
 {
 	NEW(log_reader, self);
@@ -160,6 +165,7 @@ make_log_reader(UINT32 dgram,
 	self->prefix = prefix;
 	self->max_log_line = MAX(max_log_line, pad_size) + 1;
 	self->pad_size = pad_size;
+	self->msg_flags = msg_flags;
 	self->buffer = ol_space_alloc(max_log_line);
 	
 	return &self->super;
